@@ -1,6 +1,6 @@
 #!/bin/sh
 #set -xv
-UPGRADE_VER="1.0.18"
+UPGRADE_VER="1.0.19"
 TARGET_PREFIX=sp80_upgrade_
 BIN_PATH=/home/root
 CARD_PATH=${MOUNTR}
@@ -200,6 +200,13 @@ if [ "$fl_continue" -eq "0" ]; then
  pwd | tee -a ${LOG}
  tar -x${TAR_OPT} ${TAR_FILE} productVersion.txt
  ls -l | tee -a ${LOG}
+fl_check_war=0
+prod_ver="$(cat /home/root/productVersion.txt)"
+if [[ "${prod_ver:0:2}" == "1." || "${prod_ver:0:2}" == "2." ]]; then
+ fl_check_war=1
+fi
+echo "Check ver $prod_ver [${prod_ver:0:2}] fl_check_war:${fl_check_war}"
+if [ $fl_check_war -ne 1 ]; then
  WAR_FILE=${BIN_PATH}/${WARTOOL}
  if [ -f ${WAR_FILE} ]; then
 	 echo "Checking Warranty at " $(date) | tee -a ${LOG}
@@ -211,6 +218,9 @@ if [ "$fl_continue" -eq "0" ]; then
    do_reboot 1 "Not Allowed"
 	 fi
  fi
+else
+  echo "Skip Warr for ver $prod_ver [${prod_ver:0:2}]"
+fi
 
  ##### SYSTEM upgrade ###########################
  fl_kupl=0
